# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-12 09:24
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Review',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.PositiveIntegerField(blank=True, null=True, verbose_name='Content ID')),
                ('active', models.BooleanField(default=False, verbose_name='Active')),
                ('user_name', models.CharField(blank=True, max_length=50, verbose_name='Name')),
                ('user_email', models.EmailField(blank=True, max_length=254, verbose_name='E-mail')),
                ('comment', models.TextField(blank=True, verbose_name='Comment')),
                ('score', models.FloatField(choices=[(1, '*'), (2, '**'), (3, '***'), (4, '****'), (5, '*****')], default=3.0, verbose_name='Score')),
                ('creation_date', models.DateTimeField(auto_now_add=True, verbose_name='Creation date')),
                ('ip_address', models.GenericIPAddressField(blank=True, null=True, verbose_name='IP address')),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='content_type_set_for_review', to='contenttypes.ContentType', verbose_name='Content type')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='review_comments', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
        ),
    ]



from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _

from .managers import ActiveManager
from .settings import SCORE_CHOICES


@python_2_unicode_compatible
class Review(models.Model):
    """
    A ``Review`` consists on a comment and a rating.
    """
    content_type = models.ForeignKey(ContentType, verbose_name=_(u"Content type"), related_name="content_type_set_for_%(class)s")
    object_id = models.PositiveIntegerField(_(u"Content ID"), blank=True, null=True)
    content = GenericForeignKey(ct_field="content_type", fk_field="object_id")

    active = models.BooleanField(_(u"Active"), default=False)
    # if the user is authenticated we save the user otherwise the name and the
    # email.
    user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_(u"User"), blank=True, null=True, related_name="%(class)s_comments")
    user_name = models.CharField(_(u"Name"), max_length=50, blank=True)
    user_email = models.EmailField(_(u"E-mail"), blank=True)

    comment = models.TextField(_(u"Comment"), blank=True)
    score = models.PositiveIntegerField(_(u"Score"), choices=SCORE_CHOICES)

    creation_date = models.DateTimeField(_(u"Creation date"), auto_now_add=True)
    ip_address = models.GenericIPAddressField(_(u"IP address"), blank=True, null=True)

    objects = ActiveManager()

    def __str__(self):
        return "{} ({})".format(self.name, self.score)

    @property
    def name(self):
        """
        Returns the stored user name.
        """
        if self.user is not None:
            return self.user.get_full_name()
        else:
            return self.user_name

    @property
    def email(self):
        """
        Returns the stored user email.
        """
        if self.user is not None:
            return self.user.email
        else:
            return self.user_email



from django.contrib import admin

from .models import Review


@admin.register(Review)
class ReviewAdmin(admin.ModelAdmin):
    list_display = ('name', 'email', 'score', )
    list_filter = ('score', )



from django.conf import settings
from django.utils.translation import ugettext_lazy as _


DEFAULT_SCORE_CHOICES = (
    (1, _(u"*")),
    (2, _(u"**")),
    (3, _(u"***")),
    (4, _(u"****")),
    (5, _(u"*****")),
)


SCORE_CHOICES = getattr(settings, 'SCORE_CHOICES', DEFAULT_SCORE_CHOICES)
